// This file may be redistributed and modified only under the terms of
// the GNU General Public License (See COPYING for details).
// Copyright (C) 2003 - 2007 Simon Goodall

package WFUT;

import java.io.File;

/** This code calculates the CRC32 values for a given file */
class CRC32Calc {
  /** Calculate CRC32 value of a file
   * @param filename Name of file to calculate CCRC32 value of
   * @throws FileNotFoundException Thrown if file isn't found
   * @throws IOException Thrown on read error.
   * @return CRC32 value
   */  
  public static long calcCRC32(final String filename) throws java.io.FileNotFoundException, java.io.IOException {
    // Open file into a input stream
    java.io.BufferedInputStream in = new java.io.BufferedInputStream(new java.io.FileInputStream(filename));
    // Buffer to store input data
    byte[] buffer = new byte[8192];
    int numberRead;
    java.util.zip.CRC32 crc = new java.util.zip.CRC32();
    // Read in bytes and update crc value
    while ((numberRead = in.read(buffer)) >= 0) {
      crc.update(buffer, 0, numberRead);
    }
    return crc.getValue();
  }
  
  /** Calculate CRC32 value of a file
   * @param f A valid file object representing the file to crc32 check
   * @throws FileNotFoundException Thrown if file isn't found
   * @throws IOException Thrown on read error.
   * @return CRC32 value
   */  
  public static long calcCRC32(File f) throws java.io.FileNotFoundException, java.io.IOException {
	    // Open file into a input stream
	    java.io.BufferedInputStream in = new java.io.BufferedInputStream(new java.io.FileInputStream(f));
	    // Buffer to store input data
	    byte[] buffer = new byte[8192];
	    int numberRead;
	    java.util.zip.CRC32 crc = new java.util.zip.CRC32();
	    // Read in bytes and update crc value
	    while ((numberRead = in.read(buffer)) >= 0) {
	      crc.update(buffer, 0, numberRead);
	    }
	    return crc.getValue();
	  }
}

